@@ -16,11 +16,11 @@
 #along with pydsl.  If not, see <http://www.gnu.org/licenses/>.
 
 __author__ = "Nestor Arocha"
-__copyright__ = "Copyright 2008-2012, Nestor Arocha"
+__copyright__ = "Copyright 2008-2013, Nestor Arocha"
 __email__ = "nesaro@gmail.com"
 
 
-class Token:
+class Token(object):
     """ Stores a symbol and its associated input """
     def __init__(self, terminalsymbol, string):
         self.symbol = terminalsymbol
